%define major	27
%define libname	%mklibname exiv2_ %{major}
%define libdev	%mklibname exiv2 -d

Summary:	Command line tool to access EXIF data in image files
Name:		exiv2
Version:	0.27.1
%define subrel 3
Release:	%mkrel 3
License:	GPLv2+
Group:		Graphics/Utilities
Url:		http://www.exiv2.org/
Source:		http://www.exiv2.org/builds/%{name}-%{version}-Source.tar.gz
Patch0:		exiv2-0.27.1-fix-cmake-installdir.patch
Patch1:		exiv2-0.27.1-fix-pkgconfig-file.patch
Patch2:		CVE-2019-13110.patch
Patch3:		CVE-2019-13112.patch
Patch4:		CVE-2019-13113.patch
Patch5:		CVE-2019-13114.patch
Patch6:		CVE-2019-17402.patch
Patch7:		CVE-2019-13109.patch
Patch8:		CVE-2019-13108.patch
Patch9:		CVE-2019-20421.patch
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	python2
BuildRequires:	libxslt-proc
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(zlib)

BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libssh)

%description
Exiv2 is a command line utility to access image metadata:
* print the Exif metadata of JPEG, TIFF and several RAW image formats as
  summary info, interpreted values, or the plain data for each tag
* print the IPTC metadata of JPEG images
* print, set and delete the JPEG comment of JPEG images
* set, add and delete Exif and IPTC metadata of JPEG images
* adjust the Exif timestamp (that's how it all started...)
* rename Exif image files according to the Exif timestamp
* extract, insert and delete Exif metadata, IPTC metadata and JPEG comments
* extract, insert and delete the thumbnail image embedded in the Exif metadata
* fix the Exif ISO setting of picture taken with Nikon cameras

%package -n	%{libname}
Summary:	Library to access EXIF data in image files
Group:		Graphics/Utilities
Obsoletes:	%{_lib}exiv22 < 0.16-1
 
%description -n	%{libname}
libexiv2 is a C++ library to access image metadata. libexiv2 is free
software.

The Exiv2 library provides:
* full read and write access to the Exif and IPTC metadata of
  an image through Exiv2 keys and standard C++ iterators
* a smart IPTC implementation that does not affect data that
  programs like Photoshop store in the same image segment
* Exif MakerNote support:
      o MakerNote tags can be accessed just like any other Exif metadata
      o a sophisticated write algorithm avoids corrupting the MakerNote:
          1) the MakerNote is not re-located if possible at all, and
          2) MakerNote Ifd offsets are re-calculated if the MakerNote 
             needs to be moved (for known Ifd MakerNotes)
* extract and delete methods for Exif thumbnails (both, JPEG and TIFF
  thumbnails)
* set methods for Exif thumbnails (JPEG only, TIFF thumbnails can be
  set from individual tags)
* complete API documentation (by Doxygen)

%package -n	%{libdev}
Summary: 	Headers and links to compile against the "%{libname}" library
Group:		Development/C
Requires:	%{libname} = %{version}
Requires:	multiarch-utils
Provides:	libexiv-devel = %{version}

%description -n	%{libdev}
This package contains all files which one needs to compile programs using
the "%{libname}" library.

%package	doc
Summary:	Exiv2 library documentation
Group:		Documentation
BuildArch:	noarch

%description	doc
Exiv2 library documentation.

%prep
%setup -q -n %{name}-%{version}-Source
%autopatch -p1

# remove Apple filesystem cruft
find . -type f -name "._*" -delete

%build
# exiv2: embedded copy of exempi should be compiled with BanAllEntityUsage
# https://bugzilla.redhat.com/show_bug.cgi?id=888769
export CPPFLAGS="-DBanAllEntityUsage=1"
export MAKEFILES_TYPE='Unix Makefiles'
%cmake -G "$MAKEFILES_TYPE" \
      -DEXIV2_BUILD_SAMPLES=OFF \
      -DEXIV2_BUILD_PO=ON \
      -DEXIV2_ENABLE_XMP=ON \
      -DEXIV2_ENABLE_PNG=ON \
      -DEXIV2_ENABLE_NLS=ON \
      -DEXIV2_ENABLE_PRINTUCS2=ON \
      -DEXIV2_ENABLE_LENSDATA=ON \
      -DEXIV2_ENABLE_VIDEO=OFF \
      -DEXIV2_ENABLE_WEBREADY=OFF \
      -DEXIV2_ENABLE_CURL=OFF \
      -DEXIV2_ENABLE_SSH=OFF
%make_build

%install
%make_install -C build

%find_lang exiv2

%files -f %{name}.lang
%doc COPYING README.md
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}.so.%{version}

%files -n %{libdev}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*
%{_libdir}/lib%{name}-xmp.a
%{_libdir}/cmake/%{name}/
%{_includedir}/*

%files doc
%doc doc/ChangeLog doc/cmd.txt


%changelog
* Sat Feb 08 2020 ns80 <ns80> 0.27.1-3.3.mga7
+ Revision: 1488087
- add patch for CVE-2019-20421 (mga#26171)
- add upstream patches for CVE-2019-1310[89] (mga#25280)
- add upstream patches for CVE-2019-1311[0234] and CVE-2019-17402 (mga#25280)

* Fri May 17 2019 daviddavid <daviddavid> 0.27.1-3.mga7
+ Revision: 1398146
- add patch to fix libdir path from pkgconfig file

* Mon May 13 2019 daviddavid <daviddavid> 0.27.1-2.mga7
+ Revision: 1397640
- add patch to fix cmake config files installdir path

* Mon May 13 2019 luigiwalser <luigiwalser> 0.27.1-1.mga7
+ Revision: 1397635
- 0.27.1
- remove patch (fixed upstream)

* Sat Jan 26 2019 wally <wally> 0.27.0-6.mga7
+ Revision: 1361000
- fix libdir in pkg-config .pc file for 64 bit arches

* Mon Dec 31 2018 wally <wally> 0.27.0-5.mga7
+ Revision: 1347571
- remove Apple filesystem cruft more safer way

* Mon Dec 31 2018 wally <wally> 0.27.0-4.mga7
+ Revision: 1347570
- clean Apple filesystem cruft from devel pkg

* Mon Dec 31 2018 daviddavid <daviddavid> 0.27.0-3.mga7
+ Revision: 1347552
- do not remove internal static library on libxmp.a
  * /usr/share/exiv2/cmake/exiv2Config.cmake reference this file

* Sun Dec 30 2018 daviddavid <daviddavid> 0.27.0-2.mga7
+ Revision: 1346913
- re-enable translation files

* Sat Dec 29 2018 luigiwalser <luigiwalser> 0.27.0-1.mga7
+ Revision: 1346068
- remove find_lang call due to no translations
- 0.27.0
- library major is now 27
- remove patches (issues fixed upstream)

* Sun Sep 23 2018 umeabot <umeabot> 0.26-5.mga7
+ Revision: 1297641
- Mageia 7 Mass Rebuild

* Thu Oct 26 2017 mrambo3501 <mrambo3501> 0.26-4.mga7
+ Revision: 1173806
- add upstream patch fixing seventeen CVEs (documented in patch)
- * CVE-2017-11336
- * CVE-2017-11337
- * CVE-2017-11338
- * CVE-2017-11339
- * CVE-2017-11340
- * CVE-2017-11553
- * CVE-2017-11591
- * CVE-2017-11592
- * CVE-2017-11683
- * CVE-2017-12955
- * CVE-2017-12956
- * CVE-2017-12957
- * CVE-2017-14859
- * CVE-2017-14860
- * CVE-2017-14862
- * CVE-2017-14864
- * CVE-2017-14857

* Wed Oct 25 2017 mrambo3501 <mrambo3501> 0.26-3.mga7
+ Revision: 1173620
- add upstream patch fixing segfault on photos from pentax cameras

* Tue Jun 20 2017 neoclust <neoclust> 0.26-2.mga6
+ Revision: 1107938
- Fix default build options

* Tue Jun 20 2017 akien <akien> 0.26-1.mga6
+ Revision: 1107926
- BR cmake
+ neoclust <neoclust>
- New version 0.26

* Mon Sep 05 2016 pterjan <pterjan> 0.25-4.mga6
+ Revision: 1050049
- Fix again parallel build as the patch had been disabled

* Fri Mar 04 2016 luigiwalser <luigiwalser> 0.25-3.mga6
+ Revision: 985700
- embedded copy of exempi should be compiled with BanAllEntityUsage (rhbz#888769)

* Sun Feb 14 2016 umeabot <umeabot> 0.25-2.mga6
+ Revision: 960053
- Mageia 6 Mass Rebuild

* Sun Aug 23 2015 neoclust <neoclust> 0.25-1.mga6
+ Revision: 868251
- New version 0.25

* Fri Feb 27 2015 pterjan <pterjan> 0.24-5.mga5
+ Revision: 817139
- Add opensuse patch fixing parallel build

* Thu Jan 08 2015 luigiwalser <luigiwalser> 0.24-4.mga5
+ Revision: 809356
- add upstream patch to fix CVE-2014-9449

* Wed Oct 15 2014 umeabot <umeabot> 0.24-3.mga5
+ Revision: 742701
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.24-2.mga5
+ Revision: 679062
- Mageia 5 Mass Rebuild

* Mon Feb 10 2014 dams <dams> 0.24-1.mga5
+ Revision: 588947
- new version 0.24
- update %%major
- clean specfile

* Fri Oct 18 2013 umeabot <umeabot> 0.23-4.mga4
+ Revision: 504210
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 0.23-3.mga3
+ Revision: 349867
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Fri Nov 09 2012 fwang <fwang> 0.23-2.mga3
+ Revision: 316594
- update rpm group
- update rpm group
- update rpm group

* Mon Jun 18 2012 fwang <fwang> 0.23-1.mga3
+ Revision: 261591
- update libmajor
- new version 0.23

* Sun Oct 09 2011 fwang <fwang> 0.22-1.mga2
+ Revision: 153403
- update libmajor
- new version 0.22

* Wed Apr 20 2011 pterjan <pterjan> 0.21.1-1.mga1
+ Revision: 89207
- Update to 0.21.1

* Fri Jan 14 2011 mikala <mikala> 0.21-1.mga1
+ Revision: 18068
- Drop mdk macros
- Remove BuildRoot
- imported package exiv2

